@@ -1,9 +1,8 @@
 use interoptopus::testing::assert_file_matches_generated;
-use interoptopus::testing::csharp::run_dotnet_command_if_installed;
 use interoptopus::util::NamespaceMappings;
 use interoptopus::Error;
 use interoptopus::Interop;
-use interoptopus_backend_csharp::WriteTypes;
+use interoptopus_backend_csharp::{run_dotnet_command_if_installed, WriteTypes};
 
 fn generate_bindings_multi(prefix: &str) -> Result<(), Error> {
     use interoptopus_backend_csharp::{Config, Generator};
@@ -16,7 +15,7 @@ fn generate_bindings_multi(prefix: &str) -> Result<(), Error> {
         namespace_mappings,
         unroll_struct_arrays: true,
         emit_rust_visibility: true,
-        debug: true,
+        // debug: true,
         ..Config::default()
     };
 
